from FileDO import FileDO

identifier = 'ids:dataset/999a2b6ca6ce8a0d0c88ca99b602613e83d926daf9de1c72bca5db15a399c986'
f = FileDO(identifier)
r = f.downloadFileDO()
print(r)


response_json = f.getFileLocalPath()
print(response_json)

response_json = f.getDownloadProgress()
print(response_json)



import json

import requests


class FileDO:
    def __init__(self,_identifier):
        self._identifier = _identifier
        self.service_url = 'http://127.0.0.1:21030/SCIDE/SCManager'

    def downloadFileDO(self):
        """
        获取文件的本地路径。

        参数：
            无。

        返回：
            json{'success': True, 'datas': ['ids:dataset/999a2b6ca6ce8a0d0c88ca99b602613e83d926daf9de1c72bca5db15a399c986']}

        """
        # 参数
        params = {
            'action': 'executeContract',
            'contractID': 'IODIC',
            'operation': "downloadFileDO",
            'arg': {"dpml": f"<dpml><data>{self._identifier}</data></dpml>"}
        }

        # 发送请求
        response = requests.post(self.service_url, json=params)
        parsed_json = json.loads(response.text)
        # 提取 "result" 字段
        result = parsed_json["result"]

        # 打印响应内容
        return result

    def getFileLocalPath(self):
        params = {
            'action': 'executeContract',
            'contractID': 'IODIC',
            'operation': "toLocalPath",
            'arg': {"do": f"{self._identifier}"}
        }
        # 发送请求
        response = requests.post(self.service_url, json=params)
        parsed_json = json.loads(response.text)
        # print(parsed_json)
        # 提取 "result" 字段
        filePath = parsed_json["result"]["filePath"]

        # 返回路径
        return filePath

    def getDownloadProgress(self):
        # 参数
        params = {
            'action': 'executeContract',
            'contractID': 'IODIC',
            'operation': "getDownloadProgress",
            'arg': {"do": f"{self._identifier}"}
        }

        # 发送请求
        response = requests.post(self.service_url, json=params)
        parsed_json = json.loads(response.text)
        # 提取 "result" 字段
        result = parsed_json["result"]

        # 打印响应内容
        return result





from setuptools import setup, find_packages

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='package_fileDO',
    version='0.1.0',
    packages=find_packages(),
    description='A python SDK for ioc-ic',
    long_description=long_description,
    long_description_content_type='text/markdown',  # 确保格式正确显示在 PyPI 上
    author='Cui Jingyu',
    author_email='1808662399@qq.com',
    url='https://github.com/whalecui1014',
    license='MIT',
    install_requires=[
        'requests',  # 如果你的包依赖于 requests，需要列出来
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)